@@ -90,7 +90,7 @@ badsig:
     // Get length (from motorola format)
     //length = (*pos << 24) | (*(pos+1) << 16) | (*(pos+2) << 8) | *(pos+3);
 
-    pos += sizeof(long);                    // move data pointer to the next field
+    pos += 4;                    // move data pointer to the next field
 
     printf("======= IPTC data: =======\n");
 
@@ -104,15 +104,13 @@ badsig:
         if (pos+5 > maxpos) goto corrupt;
 
         signature = (*pos << 8) + (*(pos+1));
-        pos += sizeof(short);
+        pos += 2;
 
-        if (signature != 0x1C02){
-            break;
-        }
+        if (signature != 0x1C01 && signature != 0x1c02) break;
 
         type    = *pos++;
         length  = (*pos << 8) + (*(pos+1));
-        pos    += sizeof(short);                // Skip tag length
+        pos    += 2;                          // Skip tag length
 
         if (pos+length > maxpos) goto corrupt;
         // Process tag here
@@ -174,7 +172,7 @@ corrupt:
 //--------------------------------------------------------------------------
 void ShowXmp(Section_t XmpSection)
 {
-    char * Data;
+    unsigned char * Data;
     char OutLine[101];
     int OutLineChars;
     int NonBlank;
@@ -185,7 +183,7 @@ void ShowXmp(Section_t XmpSection)
 
 
     for (a=0;a<XmpSection.Size;a++){
-        if (Data[a] >= 32){
+        if (Data[a] >= 32 && Data[a] < 128){
             OutLine[OutLineChars++] = Data[a];
             if (Data[a] != ' ') NonBlank |= 1;
         }else{
