@@ -2,12 +2,12 @@
 // Program to pull the information out of various types of EXIF digital 
 // camera files and show it in a reasonably consistent way
 //
-// Version 2.90
+// Version 2.92
 //
 // Compiling under Windows:  
 //   Make sure you have Microsoft's compiler on the path, then run make.bat
 //
-// Dec 1999 - Feb 2010
+// Dec 1999 - Dec 2011
 //
 // by Matthias Wandel   www.sentex.net/~mwandel
 //--------------------------------------------------------------------------
@@ -15,7 +15,7 @@
 
 #include <sys/stat.h>
 
-#define JHEAD_VERSION "2.90"
+#define JHEAD_VERSION "2.93"
 
 // This #define turns on features that are too very specific to 
 // how I organize my photos.  Best to ignore everything inside #ifdef MATTHIAS
@@ -25,6 +25,15 @@
     #include <io.h>
 #endif
 
+// Bitmasks for DoModify:
+#define MODIFY_ANY  1
+#define READ_ANY    2
+#define JPEGS_ONLY  4
+#define MODIFY_JPEG 5
+#define READ_JPEG   6
+static int DoModify     = FALSE;
+
+
 static int FilesMatched;
 static int FileSequence;
 
@@ -41,8 +50,6 @@ static int RenameAssociatedFiles = FALSE;
 #endif
 static char * strftime_args = NULL; // Format for new file name.
 static int Exif2FileTime  = FALSE;
-static int DoModify     = FALSE;
-static int DoReadAction = FALSE;
        int ShowTags     = FALSE;    // Do not show raw by default.
 static int Quiet        = FALSE;    // Be quiet on success (like unix programs)
        int DumpExifMap  = FALSE;
@@ -555,13 +562,6 @@ static void DoFileRenaming(const char * FileName)
         if (isdigit(FileName[a])) NumDigit += 1;
     }
 
-    if (RenameToDate <= 1){
-        // If naming isn't forced, ensure name is mostly digits, or leave it alone.
-        if (NumAlpha > 8 || NumDigit < 4){
-            return;
-        }
-    }
-
     if (!Exif2tm(&tm, ImageInfo.DateTime)){
         printf("File '%s' contains no exif date stamp.  Using file date\n",FileName);
         // Use file date/time instead.
@@ -821,7 +821,7 @@ void ProcessFile(const char * FileName)
         // Applying a command is special - the headers from the file have to be
         // pre-read, then the command executed, and then the image part of the file read.
 
-        if (!ReadJpegFile(FileName, READ_METADATA)) return;
+        if (!ReadJpegFile(FileName, DoModify & JPEGS_ONLY ? READ_METADATA : READ_ANY)) return;
 
         #ifdef MATTHIAS
             if (AutoResize){
@@ -888,7 +888,7 @@ void ProcessFile(const char * FileName)
     if (ShowConcise){
         ShowConciseImageInfo();
     }else{
-        if (!(DoModify || DoReadAction) || ShowTags){
+        if (!(DoModify) || ShowTags){
             ShowImageInfo(ShowFileInfo);
 
             {
@@ -1206,8 +1206,8 @@ badtime:
 //--------------------------------------------------------------------------
 static void Usage (void)
 {
-    printf("Jhead is a program for manipulating settings and thumnails in Exif jpeg headers\n"
-           "used by most Digital Cameras.  v"JHEAD_VERSION" Matthias Wandel, Feb 05 2010.\n"
+    printf("Jhead is a program for manipulating settings and thumbnails in Exif jpeg headers\n"
+           "used by most Digital Cameras.  v"JHEAD_VERSION" Matthias Wandel, Dec 3 2011.\n"
            "http://www.sentex.net/~mwandel/jhead\n"
            "\n");
 
@@ -1254,8 +1254,6 @@ static void Usage (void)
            "             the end of the name to make it unique.\n"
            "             The new name may include a path as part of the name.  If this path\n"
            "             does not exist, it will be created\n"
-           "  -nf[format-string]\n"
-           "             Same as -n, but rename regardless of original name\n"
            "  -a         (Windows only) Rename files with same name but different extension\n"
            "             Use together with -n to rename .AVI files from exif in .THM files\n"
            "             for example\n"
@@ -1406,43 +1404,43 @@ int main (int argc, char **argv)
     // General metadata options:
         if (!strcmp(arg,"-te")){
             ExifXferScrFile = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-dc")){
             DeleteComments = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-de")){
             DeleteExif = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-di")){
             DeleteIptc = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-dx")){
             DeleteXmp = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg, "-du")){
             DeleteUnknown = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg, "-purejpg")){
             DeleteExif = TRUE;
             DeleteComments = TRUE;
             DeleteIptc = TRUE;
             DeleteUnknown = TRUE;
             DeleteXmp = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-ce")){
             EditComment = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-cs")){
             CommentSavefileName = argv[++argn];
         }else if (!strcmp(arg,"-ci")){
             CommentInsertfileName = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-cl")){
             CommentInsertLiteral = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-mkexif")){
             CreateExifSection = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
 
     // Output verbosity control
         }else if (!strcmp(arg,"-h")){
@@ -1466,37 +1464,37 @@ int main (int argc, char **argv)
     // Thumbnail manipulation options
         }else if (!strcmp(arg,"-dt")){
             TrimExif = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-st")){
             ThumbSaveName = argv[++argn];
-            DoReadAction = TRUE;
+            DoModify |= READ_JPEG;
         }else if (!strcmp(arg,"-rt")){
             ThumbInsertName = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!memcmp(arg,"-rgt", 4)){
             RegenThumbnail = 160;
             sscanf(arg+4, "%d", &RegenThumbnail);
             if (RegenThumbnail > 320){
                 ErrFatal("Specified thumbnail geometry too big!");
             }
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
 
     // Rotation tag manipulation
         }else if (!strcmp(arg,"-autorot")){
             AutoRotate = 1;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-norot")){
             AutoRotate = 1;
             ZeroRotateTagOnly = 1;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
 
     // Date/Time manipulation options
         }else if (!memcmp(arg,"-n",2)){
             RenameToDate = 1;
-            DoReadAction = TRUE; // Rename doesn't modify file, so count as read action.
+            DoModify |= READ_JPEG; // Rename doesn't modify file, so count as read action.
             arg+=2;
             if (*arg == 'f'){
-                RenameToDate = 2;
+                // Accept -nf, but -n does the same thing now.
                 arg++;
             }
             if (*arg){
@@ -1515,7 +1513,6 @@ int main (int argc, char **argv)
             #endif
         }else if (!strcmp(arg,"-ft")){
             Exif2FileTime = TRUE;
-            DoReadAction = TRUE;
         }else if (!memcmp(arg,"-ta",3)){
             // Time adjust feature.
             int hours, minutes, seconds, n;
@@ -1531,7 +1528,7 @@ int main (int argc, char **argv)
             if (ExifTimeAdjust) ErrFatal("Can only use one of -da or -ta options at once");
             ExifTimeAdjust = hours*3600 + minutes*60 + seconds;
             if (arg[3] == '-') ExifTimeAdjust = -ExifTimeAdjust;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!memcmp(arg,"-da",3)){
             // Date adjust feature (large time adjustments)
             time_t NewDate, OldDate = 0;
@@ -1545,11 +1542,11 @@ int main (int argc, char **argv)
             }
             if (ExifTimeAdjust) ErrFatal("Can only use one of -da or -ta options at once");
             ExifTimeAdjust = NewDate-OldDate;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!memcmp(arg,"-dsft",5)){
             // Set file time to date/time in exif
             FileTimeToExif = TRUE;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!memcmp(arg,"-ds",3)){
             // Set date feature
             int a;
@@ -1573,7 +1570,7 @@ int main (int argc, char **argv)
                 ErrFatal("Date must be in format YYYY, YYYY:MM, or YYYY:MM:DD");
             }
             DateSetChars = a;
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!memcmp(arg,"-ts",3)){
             // Set the exif time.
             // Time must be specified as "yyyy:mm:dd-hh:mm:ss"
@@ -1591,7 +1588,7 @@ int main (int argc, char **argv)
             ExifTimeSet  = mktime(&tm);
 
             if ((int)ExifTimeSet == -1) ErrFatal("Time specified is out of range");
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
 
     // File matching and selection
         }else if (!strcmp(arg,"-model")){
@@ -1606,22 +1603,22 @@ int main (int argc, char **argv)
         }else if (!strcmp(arg,"-cmd")){
             if (argn+1 >= argc) Usage(); // No extra argument.
             ApplyCommand = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_ANY;
 
 #ifdef MATTHIAS
         }else if (!strcmp(arg,"-ca")){
             // Its a literal comment.  Add.
             AddComment = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-cr")){
             // Its a literal comment.  Remove this keyword.
             RemComment = argv[++argn];
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
         }else if (!strcmp(arg,"-ar")){
             AutoResize = TRUE;
             ShowConcise = TRUE;
             ApplyCommand = (char *)1; // Must be non null so it does commands.
-            DoModify = TRUE;
+            DoModify |= MODIFY_JPEG;
 #endif // MATTHIAS
         }else{
             printf("Argument '%s' not understood\n",arg);
